#!/bin/sh

#Definitions
LSI_USER_NAME="lsi"
LSI_GRP_NAME="lsi"
LSI_LOG_DIR="/tmp/LSILog"
LSI_LOG_DIR_BAK="/tmp/LSILog.bak"
LSI_BASH_PROFILE_FILE="/home/lsi/.bash_profile"


#Check for lsi group; if not exists then create
LSI_GROUP=`cat /etc/group | grep -iw lsi | awk -F ":" '{print $1}'`
if [ "$LSI_GROUP" == "" ]; then
    #Add the 'lsi' group
    groupadd lsi
else
    echo "LSI: 'lsi' group already exists"
fi

#Check for lsi user; if not exists then create
LSI_USER=`cat /etc/passwd | grep -iw lsi | awk -F ":" '{print $1}'`
if [ "$LSI_USER" == "" ]; then
    LSI_USER_PASSWD=`perl -e 'print crypt "'$LSI_USER_NAME'", "sa"'`

    #Add the 'lsi' user
    useradd -g lsi -G lsi lsi -p $LSI_USER_PASSWD
else
    echo "LSI: 'lsi' user already exists"
fi


#Check for LSILog directory; if not exists then create
if [ -d $LSI_LOG_DIR ]; then
    #Remove old dir and create new
    rm -rf $LSI_LOG_DIR
    mkdir -p $LSI_LOG_DIR
else
    #Create new dir
    mkdir -p $LSI_LOG_DIR
fi

#Change ownership for the LSI log directory
if [ -d $LSI_LOG_DIR ]; then
    chown -R lsi:lsi $LSI_LOG_DIR
fi

#Bash profile modifications for the LSI user
MakeBashProfileAdditions()
{
    lsiContent=`sed -n '/LSI.*START/,/LSI.*END/p' $LSI_BASH_PROFILE_FILE`

    if [ -e $LSI_BASH_PROFILE_FILE ] && [ "$lsiContent" == "" ]; then

        echo "" >> $LSI_BASH_PROFILE_FILE
        echo "#LSI Additions - START - DO NOT REMOVE THIS -" >> $LSI_BASH_PROFILE_FILE
        echo "lsipid=\`ps -aux | grep -w LSIShowPopup | grep -v grep | awk '{print \$2}'\`" >> $LSI_BASH_PROFILE_FILE
        echo "if [ "\$lsipid" != \"\" ]; then" >> $LSI_BASH_PROFILE_FILE
        echo "    echo \"LSI: LSIShowPopup - program already running ...\"" >> $LSI_BASH_PROFILE_FILE
        echo "else" >> $LSI_BASH_PROFILE_FILE
        echo "    /usr/bin/LSIShowPopup &" >> $LSI_BASH_PROFILE_FILE
        echo "fi" >> $LSI_BASH_PROFILE_FILE
        echo "#LSI Additions - END - DO NOT REMOVE THIS -" >> $LSI_BASH_PROFILE_FILE
        echo "" >> $LSI_BASH_PROFILE_FILE
    fi
}

if [ -e $LSI_BASH_PROFILE_FILE ]; then
    MakeBashProfileAdditions
else
    touch $LSI_BASH_PROFILE_FILE
    MakeBashProfileAdditions
fi

exit
